@@ -59,6 +59,7 @@ static QString decimalkilos(quint64 value)
     const QString prefixes("KMGTPEZY");
     int i = 0;
     quint64 curValue = value;
+    QString valueStr = QString();
     while ((i < prefixes.size()) && ((curValue > 1000) || (curValue % 1000 == 0)))
     {
         value = curValue;
@@ -69,12 +70,15 @@ static QString decimalkilos(quint64 value)
     if (i < 4) {
         quint64 diffValue = value - curValue * 1000;
         double calValue = diffValue / 1000.0 + 0.1;
-        curValue += static_cast<quint64>(calValue);;
-    }
-
-    QString valueStr = QString::number(curValue) + " ";
-    if ((i > 0) && (i <= prefixes.size())) {
-        valueStr += prefixes[i - 1];
+        curValue += static_cast<quint64>(calValue);
+        valueStr = QString::number(curValue) + " ";
+        if (i > 0)
+            valueStr += prefixes[i - 1];
+    } else if (i <= prefixes.size()) { // 单位T以上处理
+        if (value % 1000 >= 1)
+            valueStr = QString::number(value) + " " + prefixes[i - 2]; //保留小数部分 如1920GB 10001GB
+        else
+            valueStr = QString::number(curValue) + " " + prefixes[i - 1]; //无小数部分入整 如1TB
     }
     valueStr += "B";
     return valueStr;
@@ -135,6 +139,9 @@ bool DeviceStorage::setHwinfoInfo(const QMap<QString, QString> &mapInfo)
     // 希捷硬盘为ATA硬盘，无法直接获取厂商信息,只能特殊处理
     if (m_Name.startsWith("ST") && m_Vendor.isEmpty())
         m_Vendor = "ST";
+    //根据产品PN中的固定前两位 RS来匹配厂商 为Longsys 如产品PN ：RSYE3836N-480G    RSYE3836N-960G    RSYE3836N-1920     RSYE3836N-3840
+    if (m_Name.startsWith("RS") && m_Vendor.isEmpty())
+        m_Vendor = "Longsys";
 
     setAttribute(mapInfo, "Driver", m_Driver); // 驱动
     QRegExp exp("pci 0x[0-9a-zA-Z]*");
@@ -748,4 +755,7 @@ void DeviceStorage::getInfoFromsmartctl(const QMap<QString, QString> &mapInfo)
     if(Common::boardVendorType() != "KLVV" && Common::boardVendorType() != "KLVU" \
         && Common::boardVendorType() != "PGUW" && Common::boardVendorType() != "PGUV")
             m_Size.replace(QRegExp("\\.0[1-9]"), ".00");
+    //根据产品PN中的固定前两位 RS来匹配厂商 为Longsys 如产品PN ：RSYE3836N-480G    RSYE3836N-960G    RSYE3836N-1920     RSYE3836N-3840
+    if (m_Name.startsWith("RS") && m_Vendor.isEmpty())
+        m_Vendor = "Longsys";
 }
