@@ -580,7 +580,7 @@ void CmdTool::getMulHwinfoInfo(const QString &info)
             addMapInfo("hwinfo_sound", mapInfo);
         } else if (mapInfo["Hardware Class"].contains("network")) {
             //if (mapInfo.find("SysFS Device Link") != mapInfo.end() && mapInfo["SysFS Device Link"].contains("/devices/platform"))
-            bool hasAddress = mapInfo.find("HW Address") != mapInfo.end() && mapInfo.find("Permanent HW Address") != mapInfo.end();
+            bool hasAddress = mapInfo.find("HW Address") != mapInfo.end() || mapInfo.find("Permanent HW Address") != mapInfo.end();
             bool hasPath = mapInfo.find("path") != mapInfo.end();
             if (hasPath || hasAddress) {
                 addMapInfo("hwinfo_network", mapInfo);
